==> pin-2.6.12-0-cp38-cp38-manylinux_2_28_aarch64.whl: cmeel.prefix/lib/cmake/pinocchio/pinocchioTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pinocchio::pinocchio" for configuration "Release"
set_property(TARGET pinocchio::pinocchio APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio PROPERTIES
  IMPORTED_LOCATION_RELEASE "${PACKAGE_PREFIX_DIR}/lib/libpinocchio.so.2.6.12"
  IMPORTED_SONAME_RELEASE "libpinocchio.so.2.6.12"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio "${PACKAGE_PREFIX_DIR}/lib/libpinocchio.so.2.6.12" )

# Import target "pinocchio::pinocchio_pywrap" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_pywrap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_pywrap PROPERTIES
  IMPORTED_LOCATION_RELEASE "${PACKAGE_PREFIX_DIR}/lib/python3.8/site-packages/pinocchio/pinocchio_pywrap.cpython-38-aarch64-linux-gnu.so.2.6.12"
  IMPORTED_SONAME_RELEASE "pinocchio_pywrap.cpython-38-aarch64-linux-gnu.so.2.6.12"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_pywrap )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_pywrap "${PACKAGE_PREFIX_DIR}/lib/python3.8/site-packages/pinocchio/pinocchio_pywrap.cpython-38-aarch64-linux-gnu.so.2.6.12" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> pin-2.6.19-1-cp38-cp38-manylinux_2_28_aarch64.whl: cmeel.prefix/lib/cmake/pinocchio/pinocchioTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pinocchio::pinocchio" for configuration "Release"
set_property(TARGET pinocchio::pinocchio APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio PROPERTIES
  IMPORTED_LOCATION_RELEASE "${PACKAGE_PREFIX_DIR}/lib/libpinocchio.so"
  IMPORTED_SONAME_RELEASE "libpinocchio.so"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio "${PACKAGE_PREFIX_DIR}/lib/libpinocchio.so" )

# Import target "pinocchio::pinocchio_pywrap" for configuration "Release"
set_property(TARGET pinocchio::pinocchio_pywrap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pinocchio::pinocchio_pywrap PROPERTIES
  IMPORTED_LOCATION_RELEASE "${PACKAGE_PREFIX_DIR}/lib/python3.8/site-packages/pinocchio/pinocchio_pywrap.cpython-38-aarch64-linux-gnu.so"
  IMPORTED_SONAME_RELEASE "pinocchio_pywrap.cpython-38-aarch64-linux-gnu.so"
  )

list(APPEND _cmake_import_check_targets pinocchio::pinocchio_pywrap )
list(APPEND _cmake_import_check_files_for_pinocchio::pinocchio_pywrap "${PACKAGE_PREFIX_DIR}/lib/python3.8/site-packages/pinocchio/pinocchio_pywrap.cpython-38-aarch64-linux-gnu.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
